jactorch.functional.kernel
==========================

.. automodule:: jactorch.functional.kernel

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      cosine_distance
      dot
      inverse_distance
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: cosine_distance

.. autofunction:: dot

.. autofunction:: inverse_distance


